# Async AllDebrid API

Lightweight async API to interact with AllDebrid.
This version uses `attrs` and `cattrs` to parse and manipulate the responses.

Start with `alldebrid.Client("<apikey>")` to create an API client.